<template>
  <div v-if="display">
    <vciWebReferTree
        v-if="referType=='tree'"
        :key="typeKey"
        :data-key="typeKey"
        :disabled="disabled"
        :referConfig="rConfig"
        :text="textD"
        :title="titleD"
        :value="valueD"
        :width="width"
        :height="height"
        :reloadFormKey="reloadFormKey"
        @setReferValue="setValue">
    </vciWebReferTree>

    <vciWebReferTable
        v-else-if="referType=='grid'"
        :key="typeKey"
        :data-key="typeKey"
        :disabled="disabled"
        :referConfig="rConfig"
        :referType="referType"
        :text="textD"
        :title="titleD"
        :value="valueD"
        :width="width"
        :height="height"
        :reloadFormKey="reloadFormKey"
        @setReferValue="setValue">
    </vciWebReferTable>
  </div>
</template>

<script>
import vciWebReferTable from "./vciWebReferTable.vue";
import vciWebReferTree from "./vciWebReferTree.vue";
import {verifyNull} from "@/util/validate";

export default {
  name: "orgDeptRefer",
  props: {
    referConfig: {
      type: Object,
    }, value: {
      type: String,
      default: ''
    }, text: {
      type: String,
      default: ''
    }, disabled: {
      type: Boolean,
      default: false,
    }, display: {
      type: Boolean,
      default: true
    }, typeKey: {
      type: String,
      default: ''
    }, referType: {
      type: String,
      default:''
    }, width: {
      type: String,
      default:'70%'
    }, height: {
      type: String,
      default:'60%'
    },
    reloadFormKey: {
      type: String,
      default: '',
    }
  },
  components: {vciWebReferTable,vciWebReferTree },
  data() {
    return {
      emitData: {},
    };
  },
  computed: {
    rConfig() {
      let rConfig = this.referConfig;
      if (!rConfig.options) {
        rConfig.options = {};
      }
      rConfig.options.isMuti = rConfig.options.muti || rConfig.options.isMuti || false;
      rConfig.options.url='/org/deptController/referGridHasChildren';
      if(this.referType=='grid'){
        rConfig.options.tableConfig={
          cols:[{
            prop: 'code',
            label: '编号',
            sortable: true,
            width: 150,
            search: true
          }, {
            prop: 'name',
            label: '名称',
            sortable: true,
            width: 260,
            search: true
          }, {
            prop: 'description',
            label: '描述'
          }]
        };
      }
      return rConfig;
    },
    titleD(){
      let title = this.referConfig.title || "";
      title = title.replace(":", "");
      title = title
          ? "为【" + title + "】选取值"
          : "为【" + this.referConfig.showProp + "】选取值";
      return title;
    },
    textD(){
      return verifyNull(this.text) ? (this.referConfig.options.defalutText || '') : this.text;
    },
    valueD(){
      return verifyNull(this.value) ? (this.referConfig.options.defalutValue || '') :this.value;
    }
  },
  created() {
  },
  methods: {
    setValue(value) {
      this.emitData = value;
    }
  },
  watch: {
    // 修改反馈到父组件
    emitData: {
      deep: true,
      handler(newV) {
        this.$emit("setReferValue", newV);
      }
    }
  }
};
</script>

<style scoped>

</style>
